**********
Technology
**********

BackEnd:

* Python 3
* Django framework
* Django REST Framework  
* MongoDB
* Comet long polling
* SFChat protocol
* REST API
* SSL/TLS

FrontEnd:

* JQuery framework
* RequireJS
* Normalize.css
* Comet long polling
* Chat class for handling users events
* Session Storage for conversation history

